@@ -14,7 +14,7 @@ use governor::RateLimiter;
 use kitsune_p2p_timestamp::Timestamp;
 use kitsune_p2p_types::codec::Codec;
 use kitsune_p2p_types::config::*;
-use kitsune_p2p_types::dht_arc::{ArcInterval, DhtArcSet};
+use kitsune_p2p_types::dht_arc::{DhtArcRange, DhtArcSet};
 use kitsune_p2p_types::metrics::*;
 use kitsune_p2p_types::tx2::tx2_api::*;
 use kitsune_p2p_types::tx2::tx2_utils::*;
@@ -909,7 +909,7 @@ kitsune_p2p_types::write_codec_enum! {
         Initiate(0x10) {
             /// The list of arc intervals (equivalent to a [`DhtArcSet`])
             /// for all local agents
-            intervals.0: Vec<ArcInterval>,
+            intervals.0: Vec<DhtArcRange>,
             /// A random number to resolve concurrent initiates.
             id.1: u32,
             /// List of active local agents represented by this node.
@@ -920,7 +920,7 @@ kitsune_p2p_types::write_codec_enum! {
         Accept(0x20) {
             /// The list of arc intervals (equivalent to a [`DhtArcSet`])
             /// for all local agents
-            intervals.0: Vec<ArcInterval>,
+            intervals.0: Vec<DhtArcRange>,
             /// List of active local agents represented by this node.
             agent_list.1: Vec<AgentInfoSigned>,
         },
