@@ -189,7 +189,7 @@ impl HarnessInnerHandler for HarnessActor {
         let space_list = self.space_list.clone();
         Ok(async move {
             for space in space_list {
-                p2p.join(space.clone(), agent.clone()).await?;
+                p2p.join(space.clone(), agent.clone(), None).await?;
 
                 harness_chan.publish(HarnessEventType::Join {
                     agent: (&agent).into(),
@@ -211,7 +211,7 @@ impl HarnessControlApiHandler for HarnessActor {
         self.space_list.push(space.clone());
         let mut all = Vec::new();
         for (agent, (p2p, _)) in self.agents.iter() {
-            all.push(p2p.join(space.clone(), agent.clone()));
+            all.push(p2p.join(space.clone(), agent.clone(), None));
         }
         Ok(async move {
             futures::future::try_join_all(all).await?;
